# EBAT: Evaluation of Behavioural Authentication approaches Toolbox

Contemporary user authentication systems based on behavioural patterns of users are limited in 
terms of evaluation approaches, prohibiting them from gaining widespread adoption outside of the
research community. Therefore, we develop EBAT: a behavioural authentication toolbox that provides
a standardised way to evaluate and compare such authentication systems in a more comprehensive
manner and standardised. We source most popular behaviour authentication dataset, most popular evaluation metrics,
and develop new metrics that take into account aspects of evaluation so far neglected in the 
behavioural user authentication space.